# omgstatus

A cli utility to manage status from status.lol.

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install omgstatus
```

## TODO:

 - [ ] Add the ability to read global status
 - [ ] Add an helper
 - [ ] Add a real README.md
   - [ ] Define use-cases
   - [ ] Details configuration options


## License

`omgstatus` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
